/*
 * File:   Windvane.c
 * Author: Alberto Gmez Blzquez
 */


#include <xc.h>
#include <pic18f87k22.h>
#include <stdio.h>
#include "Windvane.h"

//Variables para la captura del ADC

int Value_AN6;
float VDir;
extern char TxdataWindvane[16];

/**********************************************************************
 * Function:        Capture_Windvane void)
 * PreCondition:    None
 * Input:           None	
 * Output:          Direccin del viento	
 * Overview:		Captura tensin windvane con ADC en RF1	
 ***********************************************************************/

void Capture_Windvane(void){

    //Selecciono canal AN6(RF1)
    ADCON0bits.CHS = 0b00110;
    
    //ADC ON
    ADON = 1;
    
    //Inicio captura ADC
    GO = 1; //Inicio captura del ADC
    while (DONE) {;}//Cuando finalice la captura la guarda en Value_AN6   
    Value_AN6 = ADRES; //Cuando el ADC termina la conversin DONE=0 lo graba en Value_AN6
    
    //ADC OFF
    ADON = 0;       
    
    VDir =((float)Value_AN6*3.30)/4096;
    
//Valores para divisor de tensin con alimentacin de 3.3V    
          if (VDir > 2.45 && VDir < 2.58) {
                sprintf(TxdataWindvane, "<Dir> --N--     ");
            } else if (VDir > 1.25 && VDir < 1.35) {
                sprintf(TxdataWindvane, "<Dir> --NNE--   ");
            } else if (VDir > 1.36 && VDir < 1.60) {
                sprintf(TxdataWindvane, "<Dir> --NE--    ");
            } else if (VDir > 0.24 && VDir < 0.28) {
                sprintf(TxdataWindvane, "<Dir> --ENE--   ");
            } else if (VDir > 0.29 && VDir < 0.35) {
                sprintf(TxdataWindvane, "<Dir> --E--     ");
            } else if (VDir > 0.15 && VDir < 0.23) {
                sprintf(TxdataWindvane, "<Dir> --ESE--   ");
            } else if (VDir > 0.45 && VDir < 0.65) {
                sprintf(TxdataWindvane, "<Dir> --SE--    ");
            } else if (VDir > 0.37 && VDir < 0.43) {
                sprintf(TxdataWindvane, "<Dir> --SSE--   ");
            } else if (VDir > 0.86 && VDir < 0.99) {
                sprintf(TxdataWindvane, "<Dir> --S--     ");
            } else if (VDir > 0.70 && VDir < 0.83) {
                sprintf(TxdataWindvane, "<Dir> --SSW--   ");
            } else if (VDir > 1.95 && VDir < 2.15) {
                sprintf(TxdataWindvane, "<Dir> --SW--    ");
            } else if (VDir > 1.83 && VDir < 2.00) {
                sprintf(TxdataWindvane, "<Dir> --WSW--   ");
            } else if (VDir > 2.90 && VDir < 3.20) {
                sprintf(TxdataWindvane, "<Dir> --W--     ");
            } else if (VDir > 2.50 && VDir < 2.78) {
                sprintf(TxdataWindvane, "<Dir> --WNW--   ");
            } else if (VDir > 2.81 && VDir < 2.89) {
                sprintf(TxdataWindvane, "<Dir> --NW--    ");
            } else if (VDir > 2.18 && VDir < 2.40) {
                sprintf(TxdataWindvane, "<Dir> --NNW--   ");
            } else {
                sprintf(TxdataWindvane, "<Dir> --Error-- ");
            }
    
            
            
}